Getting started
===============

There are several steps involved to setting up your ecommerce project:

.. toctree::
   :maxdepth: 2

   getting_started/installation
   getting_started/search
   getting_started/customising_models
   getting_started/overriding_core_classes
   getting_started/create_product_catalogue

